pub struct MinimumThroughputDownloadBody<B> { /* private fields */ }Expand description
A body-wrapping type that ensures data is being streamed faster than some lower limit.
If data is being streamed too slowly, this body type will emit an error next time it’s polled.
Implementations
Sourceimpl<B> MinimumThroughputDownloadBody<B>
impl<B> MinimumThroughputDownloadBody<B>
Sourcepub fn new(
time_source: impl TimeSource + 'static,
async_sleep: impl AsyncSleep + 'static,
body: B,
options: MinimumThroughputBodyOptions,
) -> Self
pub fn new( time_source: impl TimeSource + 'static, async_sleep: impl AsyncSleep + 'static, body: B, options: MinimumThroughputBodyOptions, ) -> Self
Create a new minimum throughput body.