pub fn run_classifiers_on_ctx(
classifiers: impl Iterator<Item = SharedRetryClassifier>,
ctx: &InterceptorContext,
) -> RetryActionExpand description
Given an iterator of retry classifiers and an interceptor context, run retry classifiers on the
context. Each classifier is passed the RetryAction accumulated by the previously-run
classifiers (the first classifier is passed RetryAction::NoActionIndicated) via
ClassifyRetry::classify_retry_v2, so a later classifier may refine an earlier verdict.